@@ -495,9 +495,30 @@ END
       Parallel::Forker
       UUID::Tiny
       Regexp::Assemble
-      Crypt::PassGen
 
    );
+   # http://cygwin.1069669.n5.nabble.com/where-is-my-quot-usr-dict-
+   # words-quot-or-quot-usr-share-dict-words-on-cygwin-1-7-td59328.html
+   my $words="ftp://fr2.rpmfind.net/linux/fedora/linux/releases/23/".
+         "Everything/i386/os/Packages/w/words-3.0-24.fc23.noarch.rpm";
+   ($stdout,$stderr)=$handle->cmd(
+      "wget --random-wait --progress=dot ".$words,
+      '__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "rpm2cpio words-3.0-24.fc23.noarch.rpm | \(cd /; cpio -idmv\)");
+   ($stdout,$stderr)=$handle->cmd("chmod -v 755 /usr/share/dict/",
+      '__display__');
+   my $pasgen="http://search.cpan.org/CPAN/authors/id/T/TJ/TJENNESS/".
+         "Crypt-PassGen-0.06.tar.gz";
+   ($stdout,$stderr)=$handle->cmd("
+      "wget --random-wait --progress=dot ".$pasgen,
+      '__display__');
+   ($stdout,$stderr)=$handle->cmd("tar xvf Crypt-PassGen-0.06.tar.gz",
+      '__display__');
+   ($stdout,$stderr)=$handle->cwd("Crypt-PassGen-0.06");
+   ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
+   ($stdout,$stderr)=$handle->cmd("make install",'__display__');
+   ($stdout,$stderr)=$handle->cwd("..");
    my $install_fullautoapi=<<'END';
 
           o o    o .oPYo. ooooo    .oo o     o     o o    o .oPYo.
